summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2022-02-03 15:38:21 (GMT)
committerBrad King <brad.king@kitware.com>2022-02-03 19:13:12 (GMT)
commita5a9687799ae8a591e4537c9b73718045c709778 (patch)
tree7c0485862106a90498b7b004afc4546bff1ceb0c
parenta9ffded98cb0a8cdfe95bd21069de215810c0b6f (diff)
downloadCMake-a5a9687799ae8a591e4537c9b73718045c709778.zip
CMake-a5a9687799ae8a591e4537c9b73718045c709778.tar.gz
CMake-a5a9687799ae8a591e4537c9b73718045c709778.tar.bz2
export: Increase maximum policy version in exported files to 3.22
The files generatd by `install(EXPORT)` and `export()` commands are known to work with policies as of CMake 3.22, so enable them in sufficiently new CMake versions.
-rw-r--r--Source/cmExportFileGenerator.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/cmExportFileGenerator.cxx b/Source/cmExportFileGenerator.cxx
index 412d104..bb0229f 100644
--- a/Source/cmExportFileGenerator.cxx
+++ b/Source/cmExportFileGenerator.cxx
@@ -933,13 +933,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
// policy settings for up to CMake 3.21 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake
// versions.
/* clang-format off */
os << "cmake_policy(PUSH)\n"
- << "cmake_policy(VERSION 2.6...3.21)\n";
+ << "cmake_policy(VERSION 2.6...3.22)\n";
/* clang-format on */
}
@@ -933,13 +933,13 @@ void cmExportFileGenerator::GeneratePolicyHeaderCode(std::ostream& os)
// Isolate the file policy level.
// Support CMake versions as far back as 2.6 but also support using NEW
- // policy settings for up to CMake 3.21 (this upper limit may be reviewed
+ // policy settings for up to CMake 3.22 (this upper limit may be reviewed
// and increased from time to time). This reduces the opportunity for CMake
// warnings when an older export file is later used with newer CMake